----------------------------------
pirt.deform - Deformations classes
----------------------------------

.. automodule:: pirt.deform


The base deformation class
--------------------------

.. autoclass:: pirt.Deformation
    :members:


The base grid deformation class
-------------------------------

.. autoclass:: pirt.DeformationGrid
    :members:

The base field deformation class
--------------------------------

.. autoclass:: pirt.DeformationField
    :members:

The concrete classes to use
----------------------------

.. autoclass:: pirt.DeformationGridBackward
    :members:

.. autoclass:: pirt.DeformationGridForward
    :members:

.. autoclass:: pirt.DeformationFieldBackward
    :members:

.. autoclass:: pirt.DeformationFieldForward
    :members:

.. autoclass:: pirt.DeformationIdentity
    :members:
